# eric7.Plugins.PluginEricdoc

Module implementing the Ericdoc plugin.

### Global Attributes

__header__
error

### Classes

EricdocPlugin | Class implementing the Ericdoc plugin.

### Functions

exeDisplayDataList | Public method to support the display of some executable info.

## EricdocPlugin

Class implementing the Ericdoc plugin.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

EricdocPlugin | Constructor
__doEricdoc | Private slot to perform the eric7_doc api documentation generation.
__ericdocProcessFinished | Private slot to perform actions after the documentation was generated.
__execDialogFinished | Private slot to handle the execution dialog being closed.
__initialize | Private slot to (re)initialize the plugin.
__projectShowMenu | Private slot called, when the the project menu or a submenu is about to be shown.
activate | Public method to activate this plugin.
deactivate | Public method to deactivate this plugin.

### Static Methods

None

#### EricdocPlugin (Constructor)

EricdocPlugin(ui)

Constructor

ui (UserInterface)
  reference to the user interface object

#### EricdocPlugin.__doEricdoc

__doEricdoc()

Private slot to perform the eric7_doc api documentation generation.

#### EricdocPlugin.__ericdocProcessFinished

__ericdocProcessFinished()

Private slot to perform actions after the documentation was generated.

#### EricdocPlugin.__execDialogFinished

__execDialogFinished()

Private slot to handle the execution dialog being closed.

#### EricdocPlugin.__initialize

__initialize()

Private slot to (re)initialize the plugin.

#### EricdocPlugin.__projectShowMenu

__projectShowMenu(menuName, _menu)

Private slot called, when the the project menu or a submenu is about to be shown.

menuName (str)
  name of the menu to be shown
_menu (QMenu)
  reference to the menu (unused)

#### EricdocPlugin.activate

activate()

Public method to activate this plugin.

Return:
  tuple of None and activation status

Return Type:
  bool

#### EricdocPlugin.deactivate

deactivate()

Public method to deactivate this plugin.

Up

## exeDisplayDataList

exeDisplayDataList()

Public method to support the display of some executable info.

Return:
  dictionary containing the data to query the presence of the executable

Return Type:
  dict

Up